@@ -85,7 +85,7 @@ class ListResource(Resource):
     def __getitem__(self, key):
         # Numeric index
         if isinstance(key, int):
-            # TODO: Cache length so it"s not calulated every time
+            # TODO: Cache length so it's not calulated every time
 
             self.fetch()
 
@@ -152,7 +152,7 @@ class ListResource(Resource):
     def __len__(self):
         self.fetch()
 
-        return self._page_end - self._page_start
+        return self._page_end + 1
 
     def __iter__(self):
         return self
@@ -196,6 +196,7 @@ class ListResource(Resource):
     def copy(self):
 
         new_copy = _name_to_list_class(self._name)(parent=self._parent)
+
         new_copy._filters = self._filters.copy()
 
         return new_copy
@@ -218,7 +219,7 @@ class ListResource(Resource):
             if name in copy._filter_params:
                 copy._filters[name] = value
             else:
-                raise AttributeError("%s is not a valid filter for %s" % (name, copy))
+                raise AttributeError("%s is not a valid filter for %s. valid filters are: %s" % (name, copy.__class__.__name__, copy._filter_params))
 
         return copy
 
@@ -355,6 +356,9 @@ class InstanceResource(Resource):
 
         return None
 
+    def keys(self):
+        return self._resource_data.keys()
+
     def __repr__(self):
         self.fetch()
         return str(self._resource_data)
@@ -375,7 +379,7 @@ class Client(object):
 
     __metaclass__ = ClientMetaclass
     
-    def __init__(self, account_sid=None, auth_token=None, base_url="https://api.telapi.com/2011-07-01/", *args, **kwargs):
+    def __init__(self, account_sid=None, auth_token=None, base_url="https://api.telapi.com/v1/", *args, **kwargs):
         object.__init__(self)
         self.account_sid = account_sid or os.environ.get("TELAPI_ACCOUNT_SID")
         self.auth_token  = auth_token or os.environ.get("TELAPI_AUTH_TOKEN")
